@@ -24,7 +24,9 @@ _argc_take_args() {
         while [[ $_argc_take_index -lt $_argc_len ]]; do
             _argc_take_value="${argc__args[_argc_take_index]}"
             if [[ -n "$signs" ]] && [[ "$_argc_take_value" =~ ^["$signs"] ]]; then
-                break
+                if [[ "${#_argc_take_value}" -gt 1 ]]; then
+                    break
+                fi
             fi
             _argc_take_args_values+=("$_argc_take_value")
             _argc_take_args_len=$((_argc_take_args_len + 1))
