@@ -137,7 +137,7 @@ impl<'a, 'b, T: Runtime> Matcher<'a, 'b, T> {
                         &mut is_rest_args_positional,
                         cmd,
                     );
-                } else if arg.starts_with(|c| signs.contains(c)) {
+                } else if arg.len() > 1 && arg.starts_with(|c| signs.contains(c)) {
                     if let Some((k, v)) = arg.split_once('=') {
                         if let Some(param) = cmd.find_flag_option(k) {
                             add_param_choice_fn(&mut choice_fns, param);
@@ -184,6 +184,7 @@ impl<'a, 'b, T: Runtime> Matcher<'a, 'b, T> {
                             &mut split_last_arg_at,
                             combine_shorts,
                             &signs,
+                            compgen,
                         );
                         comp_option = Some(param.id());
                     } else if let Some(subcmd) = find_subcommand(cmd, arg, &positional_args)
@@ -240,6 +241,7 @@ impl<'a, 'b, T: Runtime> Matcher<'a, 'b, T> {
                                 &mut split_last_arg_at,
                                 combine_shorts,
                                 &signs,
+                                compgen,
                             );
                             comp_option = Some(param.id());
                         }
@@ -1181,14 +1183,18 @@ fn take_value_args<'a>(
     len: usize,
     signs: &str,
     assigned: bool,
+    compgen: bool,
 ) -> Vec<&'a str> {
     let mut output = vec![];
     if assigned || len == 0 {
         return output;
     }
-    let end = (start + len).min(args.len());
-    for arg in args.iter().take(end).skip(start) {
-        if arg.starts_with(|c| signs.contains(c)) {
+    let args_len = args.len();
+    let end = (start + len).min(args_len);
+    for (i, arg) in args.iter().enumerate().take(end).skip(start) {
+        if arg.starts_with(|c| signs.contains(c))
+            && (arg.len() > 1 || (compgen && i == args_len - 1))
+        {
             break;
         }
         output.push(arg.as_str());
@@ -1238,6 +1244,7 @@ fn match_flag_option<'a, 'b>(
     split_last_arg_at: &mut Option<usize>,
     combine_shorts: bool,
     signs: &str,
+    compgen: bool,
 ) {
     let arg = &args[*arg_index];
     if param.terminated() {
@@ -1251,7 +1258,7 @@ fn match_flag_option<'a, 'b>(
     } else if let Some(prefix) = param.match_prefix(arg) {
         let args_len = args.len();
         let prefix_len = prefix.len();
-        let value_args = take_value_args(args, *arg_index + 1, 1, signs, param.assigned());
+        let value_args = take_value_args(args, *arg_index + 1, 1, signs, param.assigned(), compgen);
         let take_empty = value_args.is_empty();
         *arg_index += value_args.len();
         let values = if take_empty { vec!["1"] } else { value_args };
@@ -1265,7 +1272,14 @@ fn match_flag_option<'a, 'b>(
     } else {
         let values_max = param.num_args().1;
         let args_len = args.len();
-        let value_args = take_value_args(args, *arg_index + 1, values_max, signs, param.assigned());
+        let value_args = take_value_args(
+            args,
+            *arg_index + 1,
+            values_max,
+            signs,
+            param.assigned(),
+            compgen,
+        );
         *arg_index += value_args.len();
         if *arg_index == args_len - 1 {
             if *arg_comp != ArgComp::FlagOrOption {
